% Make predictions using a trained, two-class linear discriminant classifier.
% Inputs:       X - N x D (test) feature data matrix
%               Y - (N x 1) (test) label vector with values {1,2}
%             lda - LDA model returned from ldatrain.m
% Outputs:      E - Prediction accuracy
%            Yhat - N x 1 predicted labels
%             nll - N x 2 matrix of negative log likelihoods per prediction
%                   and class
% 
% (cc) Attribution-ShareAlike 3.0, Max Little, 2020. If you use this code,
% please cite M.A. Little, R. Badawy, "Causal Bootstrapping", 2019,
% arXiv:1910.09648

function [E,Yhat,nll] = ldapredict(X,Y,lda)
N = size(X,1);
nll = NaN(N,2);
for n = 1:N
    nll(n,1) = 1/2*(X(n,:)-lda.mu(1,:))*inv(lda.S)*(X(n,:)-lda.mu(1,:))'-log(lda.p(1));
    nll(n,2) = 1/2*(X(n,:)-lda.mu(2,:))*inv(lda.S)*(X(n,:)-lda.mu(2,:))'-log(lda.p(2));
end
[l,Yhat] = min(nll,[],2);
E = sum(Y==Yhat)/N;
