% Train a two-class linear discriminant classifier.
% Inputs:       X - N x D feature data matrix
%               Y - (N x 1) label vector with values {1,2}
% Outputs: lda.mu - 2 x D mean vectors
%          lda.S  - D x D shared covariance matrix
%          lda.p  - 2 x 1 vector of class probabilities
% 
% (cc) Attribution-ShareAlike 3.0, Max Little, 2020. If you use this code,
% please cite M.A. Little, R. Badawy, "Causal Bootstrapping", 2019,
% arXiv:1910.09648

function lda = ldatrain(X,Y)
N = size(X,1);
mu(1,:) = mean(X(Y==1,:));
mu(2,:) = mean(X(Y==2,:));
S1 = cov(X(Y==1,:));
S2 = cov(X(Y==2,:));
p(1) = sum(Y==1)/N;
p(2) = sum(Y==2)/N;
S = p(1)*S1+p(2)*S2;
lda.mu = mu;
lda.S = S;
lda.p = p;
