% Use the Gumbel-max trick to draw N samples (returned in Nx1 vector x)
% from a categorical distribution with K-1 parameter vector p. This is
% designed for situations when the probabilities have very large numerical
% range.
% 
% (cc) Attribution-ShareAlike 3.0, Max Little, 2020. If you use this code,
% please cite M.A. Little, R. Badawy, "Causal Bootstrapping", 2019,
% arXiv:1910.09648

function x = rand_cat_robust(p,N)
p = p(:);
K = length(p);
logp = log(p);
u = rand(N,K);
epsilon = -log(-log(u));
[v,x] = max(epsilon + repmat(logp',N,1),[],2);
